@@ -27,4 +27,4 @@ class SoftwarePersistencePlugin(Plugin):
     COMPATIBLE_HIVE = SOFTWARE_HIVE_TYPE
 
     def run(self):
-        return get_subkey_values_from_list(self.registry_hive, PERSISTENCE_ENTRIES, as_json=self.as_json)
+        self.entries = get_subkey_values_from_list(self.registry_hive, PERSISTENCE_ENTRIES, as_json=self.as_json)
